@@ -41,10 +41,7 @@ class Value:
         if inst is None:
             return self.schema
 
-        try:
-            return inst.__dict__[self.name]
-        except KeyError:
-            raise AttributeError(self.name)
+        return inst.__dict__.get(self.name)
 
     def __set__(self, inst, value):
         inst.__dict__[self.name] = value
